BlockedUsersRequest class

Properties

direction → String?
final
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
limit → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword → String?
final
token → int?
final

Methods

fetchNext({required dynamic onSuccess(List<User> userList)?, required dynamic onError(CometChatException excep)?}) → Future<List<User>>
fetch the list of Users that logged-in user have blocked.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultLimit → int
final
directionBlockedByMe → String
final
directionBoth → String
final
directionHasBlockedMe → String
final
maxLimit → int
final