BlockedUsersRequestBuilder class

Properties

direction ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
limit ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword ↔ String?
getter/setter pair
token ↔ int?
getter/setter pair

Methods

build() → BlockedUsersRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited