ConversationsRequest class

Properties

conversationType → String?
final
hashCode → int
The hash code for this object.
no setterinherited
init ↔ bool?
getter/setter pair
key ↔ String?
getter/setter pair
limit → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags → List<String>?
final
withTags → bool?
final
withUserAndGroupTags → bool?
final

Methods

fetchNext({required dynamic onSuccess(List<Conversation> message)?, required dynamic onError(CometChatException excep)?}) → Future<List<Conversation>>
Returns a list of Conversation object fetched after putting the filters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Constants

defaultLimit → const int
maxLimit → const int