GroupMembersRequest class

Properties

guid → String
final
hashCode → int
The hash code for this object.
no setterinherited
key ↔ String?
getter/setter pair
limit → int
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scopes → List<String>?
final
searchKeyword → String?
final

Methods

fetchNext({required dynamic onSuccess(List<GroupMember> groupMemberList)?, required dynamic onError(CometChatException excep)?}) → Future<List<GroupMember>>
fetch the list of groups members for a group , returns List of GroupMember.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

maxLimit → int
final

Constants

defaultLimit → const int