GroupsRequest class

Properties

hashCode → int
The hash code for this object.
no setterinherited
joinedOnly → bool?
final
key ↔ String?
getter/setter pair
limit → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword → String?
final
tags → List<String>?
final
withTags → bool?
final

Methods

fetchNext({required dynamic onSuccess(List<Group> groupList)?, required dynamic onError(CometChatException excep)?}) → Future<List<Group>>
Returns list of Group object fetched after putting the filters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

maxLimit → int
final

Constants

defaultLimit → const int