MessagesRequest class

Properties

categories → List<String>?
final
category → String?
final
guid → String?
final
hashCode → int
The hash code for this object.
no setterinherited
hideDeleted → bool?
final
hideMessagesFromBlockedUsers → bool?
final
hideReplies → bool?
final
key ↔ String?
getter/setter pair
limit → int?
final
messageId → int?
final
parentMessageId → int?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword → String?
final
tags → List<String>?
final
timestamp → DateTime?
final
type → String?
final
types → List<String>?
final
uid → String?
final
unread → bool?
final
updatedAfter → DateTime?
final
updatesOnly → bool?
final
withTags → bool?
final

Methods

fetchNext({required dynamic onSuccess(List<BaseMessage> message)?, required dynamic onError(CometChatException excep)?}) → Future<List<BaseMessage>>
Returns a list of BaseMessage object fetched after putting the filters.
fetchPrevious({required dynamic onSuccess(List<BaseMessage> message)?, required dynamic onError(CometChatException excep)?}) → Future<List<BaseMessage>>
Returns a list of BaseMessage object fetched after putting the filters.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

defaultLimit → int?
final
maxLimit → int?
final