MessagesRequestBuilder class

Constructors

MessagesRequestBuilder()

Properties

categories ↔ List<String>?
getter/setter pair
category ↔ String?
getter/setter pair
guid ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideDeleted ↔ bool?
getter/setter pair
hideMessagesFromBlockedUsers ↔ bool?
getter/setter pair
hideReplies ↔ bool?
getter/setter pair
limit ↔ int?
getter/setter pair
messageId ↔ int?
getter/setter pair
parentMessageId ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword ↔ String?
getter/setter pair
tags ↔ List<String>?
getter/setter pair
timestamp ↔ DateTime?
getter/setter pair
type ↔ String?
getter/setter pair
types ↔ List<String>?
getter/setter pair
uid ↔ String?
getter/setter pair
unread ↔ bool?
getter/setter pair
updatedAfter ↔ DateTime?
getter/setter pair
updatesOnly ↔ bool?
getter/setter pair
withTags ↔ bool?
getter/setter pair

Methods

build() → MessagesRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited