UsersRequest class

Properties

currentPage → int?
final
friendsOnly → bool?
final
hashCode → int
The hash code for this object.
no setterinherited
hideBlockedUsers → bool?
final
inProgress → bool?
final
key ↔ String?
getter/setter pair
limit → int?
final
nextPage → int?
final
role → String?
final
roles → List<String>?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword → String?
final
tags → List<String>?
final
token → int?
final
totalPages → int?
final
uids → List<String>?
final
userStatus → String?
final
withTags → bool?
final

Methods

fetchNext({required dynamic onSuccess(List<User> userList)?, required dynamic onError(CometChatException excep)?}) → Future<List<User>>
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited