UsersRequestBuilder class

Constructors

UsersRequestBuilder()

Properties

currentPage ↔ int?
getter/setter pair
friendsOnly ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hideBlockedUsers ↔ bool?
getter/setter pair
inProgress ↔ bool?
getter/setter pair
limit ↔ int?
getter/setter pair
nextPage ↔ int?
getter/setter pair
role ↔ String?
getter/setter pair
roles ↔ List<String>?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
searchKeyword ↔ String?
getter/setter pair
tags ↔ List<String>?
getter/setter pair
token ↔ int?
getter/setter pair
totalPages ↔ int?
getter/setter pair
uids ↔ List<String>?
getter/setter pair
userStatus ↔ String?
getter/setter pair
withTags ↔ bool?
getter/setter pair

Methods

build() → UsersRequest
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited