Conversation class

Constructors

Conversation({String? conversationId, required String conversationType, required AppEntity conversationWith, BaseMessage? lastMessage, DateTime? updatedAt, int? unreadMessageCount = 0, List<String>? tags})
Conversation.fromMap(dynamic map)
factory

Properties

conversationId ↔ String?
getter/setter pair
conversationType ↔ String
getter/setter pair
conversationWith ↔ AppEntity
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
lastMessage ↔ BaseMessage?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tags ↔ List<String>?
getter/setter pair
unreadMessageCount ↔ int?
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited