Group class

Inheritance

Constructors

Group({required String guid, String owner = '', required String name, String? icon, String? description, bool hasJoined = false, int membersCount = 0, DateTime? createdAt, DateTime? joinedAt, DateTime? updatedAt, Map<String, dynamic>? metadata, List<String> tags = const [], required String type, String? scope, String? password})
Group.fromMap(dynamic map)
factory

Properties

createdAt ↔ DateTime?
getter/setter pair
description ↔ String?
getter/setter pair
guid ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
hasJoined ↔ bool
getter/setter pair
icon ↔ String?
getter/setter pair
joinedAt ↔ DateTime?
getter/setter pair
membersCount ↔ int
getter/setter pair
metadata ↔ Map<String, dynamic>?
getter/setter pair
name ↔ String
getter/setter pair
owner ↔ String
getter/setter pair
password ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
getter/setter pair
tags ↔ List<String>
getter/setter pair
type ↔ String
getter/setter pair
updatedAt ↔ DateTime?
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Function internally used to convert object to map
toMap() → Map<String, dynamic>
Returns map of item
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited