GroupMember class

Inheritance

Constructors

GroupMember({required String? scope, DateTime? joinedAt, required String uid, required String name, String? avatar, String? link, required String role, required String status, String? statusMessage, DateTime? lastActiveAt, List<String>? tags, Map<String, dynamic>? metadata, bool? hasBlockedMe, bool? blockedByMe})
GroupMember.fromMap(dynamic map)
factory
GroupMember.fromUid({required String? scope, required String uid, required String name})

Properties

avatar ↔ String?
getter/setter pairinherited
blockedByMe ↔ bool?
getter/setter pairinherited
hasBlockedMe ↔ bool?
getter/setter pairinherited
hashCode → int
The hash code for this object.
no setterinherited
joinedAt ↔ DateTime?
getter/setter pair
lastActiveAt ↔ DateTime?
getter/setter pairinherited
getter/setter pairinherited
metadata ↔ Map<String, dynamic>?
getter/setter pairinherited
name ↔ String
getter/setter pairinherited
role ↔ String?
getter/setter pairinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope ↔ String?
getter/setter pair
status ↔ String?
getter/setter pairinherited
statusMessage ↔ String?
getter/setter pairinherited
tags ↔ List<String>?
getter/setter pairinherited
uid ↔ String
getter/setter pairinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toMap() → Map<String, dynamic>
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited